.. testsetup:: *

   from pwnlib.rop.call import *

:mod:`pwnlib.rop.call` --- Return Oriented Programming Function Calling
=======================================================================

.. automodule:: pwnlib.rop.call
   :members:
